==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/popup-trigger.cc <==
//$Id: popup-trigger.cc,v 1.14 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "popup-trigger.h"
#include "popup-trigger-canvas.h"

#include "form-editor.h"

using Guikachu::Widgets::PopupTrigger;
using namespace Guikachu::GUI::FormEditor;

PopupTrigger::PopupTrigger (Resources::Form   *owner,
			    const std::string &id):
    Widget (owner, id),
    Resizeable (changed),
    Textual (changed, id),
    editor (0),
    list_id (changed, owner),
    usable (changed, true),
    anchor_right (changed, false)
{
}

PopupTrigger::~PopupTrigger ()
{
    if (editor)
	delete editor;
}

Gtk::Widget *PopupTrigger::create_editor ()
{
    if (!editor)
	editor = new PopupTriggerProperties (this);
    
    return editor->get_editor ();
}

CanvasItem* PopupTrigger::create_canvas_item (GUI::FormEditor::Form *form)
{
    return new PopupTriggerCanvasItem (this, form);
}

bool PopupTrigger::load (StorageNode &node)
{
    /* Non-NULL default values */
    usable = false;

    for (StorageNode curr_node  = node.children ();
	 curr_node; curr_node++)
    {
	if (curr_node.name () == "pos")
	{
	    x = curr_node.get_prop<int> ("x");
	    y = curr_node.get_prop<int> ("y");

	    std::string width_str = curr_node.get_prop<std::string> ("width");
	    if (width_str == "auto")
	    {
		manual_width = false;
		width = 0;
	    } else {
		manual_width = true;
		width = atoi (width_str.c_str ());
	    }
	    
	    std::string height_str = curr_node.get_prop<std::string> ("height");
	    if (height_str == "auto")
	    {
		manual_height = false;
		height = 0;
	    } else {
		manual_height = true;
		height = atoi (height_str.c_str ());
	    }
	}
	else if (curr_node.name () == "text")
	{
	    text = curr_node.get_content ();
	    font = curr_node.get_prop<int> ("font");
	}
	else if (curr_node.name () == "usable")
	    usable = true;
	else if (curr_node.name () == "anchor_right")
	    anchor_right = true;
	else if (curr_node.name () == "popuplist")
	    list_id = curr_node.get_prop<std::string> ("id");
	else
	    g_warning ("Error parsing `popup-trigger' widget: "
		       "unexpected element `%s'",
		       curr_node.name ().c_str ());
    }

    changed ();

    return true;
}

void PopupTrigger::save (StorageNode &node) const
{
    StorageNode my_node;

    /* Position */
    my_node = node.add_node ("pos");
    my_node.set_prop ("x", x);
    my_node.set_prop ("y", y);

    /* Size */
    if (manual_width)
	my_node.set_prop ("width", width);
    else
	my_node.set_prop ("width", "auto");

    if (manual_height)
	my_node.set_prop ("height", height);
    else
	my_node.set_prop ("height", "auto");
    
    /* Usable */
    if (usable)
	node.add_node ("usable");

    /* Anchor_right */
    if (anchor_right)
	node.add_node ("anchor_right");
    
    /* Label and font */
    my_node = node.add_node ("text", text);
    my_node.set_prop ("font", font);

    if (list_id != "")
	node.add_node ("popuplist").set_prop ("id", list_id);
}

void PopupTrigger::save_rcp (std::ostream &ostr) const
{
    gchar *width_str, *height_str;

    if (manual_width)
	width_str = g_strdup_printf ("%d", width ());
    else
	width_str = g_strdup ("AUTO");
    
    if (manual_height)
	height_str = g_strdup_printf ("%d", height ());
    else
	height_str = g_strdup ("AUTO");

    ostr << "  POPUPTRIGGER \"" << text << "\" ID " << id;
    ostr << " AT (" << x << " " << y << " " << width_str << " " << height_str << ")";
    ostr << " FONT " << font;
    if (usable)
	ostr << " USABLE";
    else
	ostr << " NONUSABLE";
    if (anchor_right)
	ostr << " RIGHTANCHOR";
    else
	ostr << " LEFTANCHOR";
    
    ostr << std::endl;

    if (list_id != "")
	ostr << "  POPUPLIST ID " << id << " " << list_id << std::endl;
    
    g_free (height_str);
    g_free (width_str);
}

int PopupTrigger::get_auto_width () const
{
    return get_string_width (font, text) + 16;
}

int PopupTrigger::get_auto_height () const
{
    return get_font_height (font);
}

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/popup-trigger.cc <==
//$Id: popup-trigger.cc,v 1.28 2004/01/18 21:14:37 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "popup-trigger.h"

#include "form-editor.h"

using Guikachu::Widgets::PopupTrigger;
using namespace Guikachu::GUI::FormEditor;

PopupTrigger::PopupTrigger (Resources::Form   *owner,
			    const std::string &id,
			    serial_t           serial):
    Widget (owner, id, serial),
    ResizeableWidget (changed),
    AutoWidth (changed),
    AutoHeight (changed),
    Textual (changed, id),
    Graphical (changed, owner->get_manager ()),

    list_id (changed, owner),
    usable (changed, true),
    anchor_right (changed, false)
{
}

int PopupTrigger::get_auto_width () const
{
    return 16 + get_line_width (font, text);
}

int PopupTrigger::get_auto_height () const
{
    return get_font_height (font) + 1;
}
